﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.Xml.Serialization;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;


namespace DataGrid
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            this.gridGroupingControl1.AllowProportionalColumnSizing = true;
            this.gridGroupingControl1.TableOptions.ListBoxSelectionMode = SelectionMode.MultiExtended;
            this.gridGroupingControl1.DataSource = GetTable();

            this.gridGroupingControl1.TableDescriptor.SortedColumns.Changed += SortedColumns_Changed;
        }

        //Change the current cell to first row while sorting the records.
        void SortedColumns_Changed(object sender, Syncfusion.Collections.ListPropertyChangedEventArgs e)
        {
            GridCurrentCell currentCell = this.gridGroupingControl1.TableControl.CurrentCell;
            if (currentCell != null)
            {
                this.gridGroupingControl1.TableControl.CurrentCell.MoveTo(this.gridGroupingControl1.TableControl.TopRowIndex, currentCell.ColIndex, GridSetCurrentCellOptions.SetFocus);
            }
        }
        public DataTable GetTable()
        {
            DataTable table = new DataTable();
            table.Columns.Add("CategoryID", typeof(int));
            table.Columns.Add("CategoryName", typeof(string));
            table.Columns.Add("Decs_Id", typeof(int));
            table.Columns.Add("Description", typeof(string));

            Random rand = new Random();
            int r = rand.Next(100);
            for (int i = 1; i <= 50; i++)
            {
                DataRow row = table.NewRow();

                row[0] = i;
                row[1] = "CategoryName" + r.ToString();
                row[2] = r;
                row[3] = "Description" + r.ToString();

                table.Rows.Add(row);
                r = rand.Next(100);
            }
            return table;

        }
        private void button1_Click(object sender, EventArgs e)
        {
            //XML Serialization.
            List<GridSelectedRecordsCollection> SelectedRecordsList = new List<GridSelectedRecordsCollection>();

            foreach (SelectedRecord record in this.gridGroupingControl1.Table.SelectedRecords)
            {
                SelectedRecordsList.Add(new GridSelectedRecordsCollection() { RecordID = this.gridGroupingControl1.Table.Records.IndexOf(record.Record) });
            }
            XmlSerializer xmlSerializer = new XmlSerializer(typeof(List<GridSelectedRecordsCollection>));
            XmlTextWriter xmlWriter = new XmlTextWriter("SelectedRecords.xml", System.Text.Encoding.UTF8);
            xmlSerializer.Serialize(xmlWriter, SelectedRecordsList);
            xmlWriter.Close();

            this.gridGroupingControl1.DataSource = null;
            SelectedRecordsList.Clear();

            //XML De-serialization
            XmlReader xr = new XmlTextReader("SelectedRecords.xml");
            XmlSerializer serializer = new XmlSerializer(typeof(List<GridSelectedRecordsCollection>));
            SelectedRecordsList = (List<GridSelectedRecordsCollection>)serializer.Deserialize(xr);

            this.gridGroupingControl1.DataSource = GetTable();

            foreach (GridSelectedRecordsCollection record in SelectedRecordsList)
            {
                this.gridGroupingControl1.Table.SelectedRecords.Add(this.gridGroupingControl1.Table.Records[record.RecordID]);
            }
            xr.Close();
        }
    }
    public class GridSelectedRecordsCollection
    {
        public GridSelectedRecordsCollection()
        {
        }
        public int RecordID
        {
            get;
            set;
        }
    }
}
